monkey.mailman.pedestal

Interceptor implementation for Mailman that uses Pedestal as backing

Interceptor implementation for Mailman that uses Pedestal as backing
raw docstring

->interceptorclj

Converts its argument to an interceptor

Converts its argument to an interceptor
sourceraw docstring

executeclj

(execute interceptors ctx)

Interceptor executor that can be passed as an :executor to the router

Interceptor executor that can be passed as an `:executor` to the router
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries