Interceptor implementation for Mailman that uses Pedestal as backing
Interceptor implementation for Mailman that uses Pedestal as backing
Converts its argument to an interceptor
Converts its argument to an interceptor
(execute interceptors ctx)Interceptor executor that can be passed as an :executor to the router
Interceptor executor that can be passed as an `:executor` to the router
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |